.. _ref_index_api:

=============
API reference
=============

This section describes all API classes, functions, and attributes in PyEDB-Core modules.

*******
Modules
*******

.. toctree::
   :maxdepth: 1

   database
   definition
   geometry
   hierarchy
   layer
   layout
   layout_instance
   net
   primitive
   session
   simulation_setup
   terminal
   utility
   release_notes
   glossary
